package market.Mes.anneal.mapper;
import java.util.HashMap;
import java.util.List;

import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.Select;
import org.springframework.test.context.jdbc.Sql;

import market.Mes.anneal.vo.WorkReportTemp;

import com.hnshituo.orm.GenericMapper;

public interface WorkReportTempMapper extends GenericMapper<WorkReportTemp,Object> {

	List<WorkReportTemp> doDiaoduQueryWeb(WorkReportTemp object, String memo1);

	void doDelete(WorkReportTemp pscp11, String string);

	Double doQueryYueLei(WorkReportTemp pscp,String str);
	
	Double doQueryYearLei(WorkReportTemp pscp,String str);

	void doDeleteWrk(String machine_code, String wrk_date);
	
	@Select("${sql}")
	public List<HashMap> doQueryWorkTemp(@Param("sql")String sql);
}
